core library
Classes
- Disposable
- Something disposable.
- Initializer
- Provides a standardized way to initialize something.
-
ReadOnlyCompleter<
T> - A wrapper for Completer to expose only future and isCompleted.
- StarterStopperAsync
- As it names says: start and stop provides a standardized way to start and stop something.
Extensions
-
ReadOnlyCompleterOnCompleterExtension
on Completer<
T> - Extension.
Exceptions / Errors
- DisposedException
- Thrown when an object was disposed and can't be used anymore.
- StopForcedException
- Stop was forced.