StarterStopperAsync class abstract mixin

As it names says: start and stop provides a standardized way to start and stop something.

The stop should gratefully stop something when force is false.

Annotations

Constructors

StarterStopperAsync()

Properties

currentWorkCompleter ReadOnlyCompleter<void>?
Completer, which completes when current work will be stopped.
no setter
hashCode int
The hash code for this object.
no setterinherited
isRunning bool
Is some operation is running now?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() ReadOnlyCompleter<void>
Starts something.
stop({bool force = false, String? forceReason}) → void
Stops what was started.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited