StopForcedException class final

Stop was forced.

Implemented types
Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
objectName String
Object name or <optimized_out>#hash.
final
reason String?
Reason of why stop is force.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited