DartThingsExtensionOnIterable<E> extension

Iterable extension.

on

Methods

equals(Iterable<E>? other, [bool equals(E, E) = _defaultEquals]) bool

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

Whether other has the same elements as this iterable. Length and order dependent.
mapFirstOrNull<C>(C? predicateAndMap(E)) → C?

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

Returns first non-null result of predicateAndMap or null if there is no non-null results for any item in this iterable.
max([Comparator<E>? compare]) → E?

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

Returns the maximum value in iterable, according to the order specified by the compare function, or null if iterable is empty.
maxBy<C extends Comparable<C>>(C getComparable(E)) → E?

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

Returns the maximum value in iterable, according to the order specified by a Comparable returned by getComparable, or null if iterable is empty.
min([Comparator<E>? compare]) → E?

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

Returns the minimum value in iterable, according to the order specified by the compare function, or null if iterable is empty.
minBy<C extends Comparable<C>>(C getComparable(E)) → E?

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

Returns the minimum value in iterable, according to the order specified by a Comparable returned by getComparable, or null if iterable is empty.
toMap<K>(K getKey(E)) Map<K, E>

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

Creates a map from this Iterable using it's value as map values and results of getKey as keys.
withEnd(E end) Iterable<E>

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

This iterable with end at the end.
without(E something) Iterable<E>

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

This iterable without something.
withStart(E start) Iterable<E>

Available on Iterable<E>, provided by the DartThingsExtensionOnIterable extension

This iterable with start at the start.