BasicPoller<T> class abstract mixin

Implemented types
Implementers

Constructors

BasicPoller()

Properties

debugLabel String?
no setter
delay Duration?
no setter
hashCode int
The hash code for this object.
no setterinherited
isAlive bool
Whether this poller is started or not (it can be alive when paused).
no setteroverride
isPaused bool
Whether this poller is paused or not.
no setteroverride
onError Function?
Error handler.
no setterinherited
onResult → void Function(T)
Result handler.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Disposes object, stopping polling.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<void>
Pauses polling.
override
poll() Future<Vote<T>>
resume() → void
Resumes polling after pause.
override
start() Future<void>
Initially starts polling.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited