PollerFromHandlers<T> class final

Inheritance

Constructors

PollerFromHandlers({required void onResult(T), Function? onError, String? debugLabel, required Future<Vote<T>> poll(), Duration? delay})

Properties

debugLabel String?
final
delay Duration?
final
hashCode int
The hash code for this object.
no setterinherited
isAlive bool
Whether this poller is started or not (it can be alive when paused).
no setterinherited
isPaused bool
Whether this poller is paused or not.
no setterinherited
onError Function?
Error handler.
final
onResult → void Function(T)
Result handler.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Disposes object, stopping polling.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<void>
Pauses polling.
inherited
poll() Future<Vote<T>>
override
resume() → void
Resumes polling after pause.
inherited
start() Future<void>
Initially starts polling.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited