notBlankOrNull property
String?
get
notBlankOrNull
Returns this string if this string is not blank, otherwise null.
Implementation
String? get notBlankOrNull => isBlankOrEmpty ? null : this;
Returns this string if this string is not blank, otherwise null.
String? get notBlankOrNull => isBlankOrEmpty ? null : this;