DisposedException class final
Thrown when an object was disposed and can't be used anymore.
- Implemented types
Constructors
- DisposedException(String objectName, [String? methodName])
- Main ctor.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodName → String?
-
A method from which this exception was thrown.
final
- objectName → String
-
An object name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited