DartThingsExtensionOnIterable<E> extension
Iterable extension.
- on
-
- Iterable<
E>
- Iterable<
Methods
-
equals(
Iterable< E> ? other, [bool equals(E, E) = _defaultEquals]) → bool -
Available on Iterable<
WhetherE> , provided by the DartThingsExtensionOnIterable extensionotherhas the same elements as this iterable. Length and order dependent. -
mapFirstOrNull<
C> (C? predicateAndMap(E)) → C? -
Available on Iterable<
Returns first non-null result ofE> , provided by the DartThingsExtensionOnIterable extensionpredicateAndMapor null if there is no non-null results for any item in this iterable. -
max(
[Comparator< E> ? compare]) → E? -
Available on Iterable<
Returns the maximum value in iterable, according to the order specified by theE> , provided by the DartThingsExtensionOnIterable extensioncomparefunction, ornullif iterable is empty. -
maxBy<
C extends Comparable< (C> >C getComparable(E)) → E? -
Available on Iterable<
Returns the maximum value in iterable, according to the order specified by a Comparable returned byE> , provided by the DartThingsExtensionOnIterable extensiongetComparable, ornullif iterable is empty. -
min(
[Comparator< E> ? compare]) → E? -
Available on Iterable<
Returns the minimum value in iterable, according to the order specified by theE> , provided by the DartThingsExtensionOnIterable extensioncomparefunction, ornullif iterable is empty. -
minBy<
C extends Comparable< (C> >C getComparable(E)) → E? -
Available on Iterable<
Returns the minimum value in iterable, according to the order specified by a Comparable returned byE> , provided by the DartThingsExtensionOnIterable extensiongetComparable, ornullif iterable is empty. -
toMap<
K> (K getKey(E)) → Map< K, E> -
Available on Iterable<
Creates a map from this Iterable using it's value as map values and results ofE> , provided by the DartThingsExtensionOnIterable extensiongetKeyas keys. -
withEnd(
E end) → Iterable< E> -
Available on Iterable<
This iterable withE> , provided by the DartThingsExtensionOnIterable extensionendat the end. -
without(
E something) → Iterable< E> -
Available on Iterable<
This iterable withoutE> , provided by the DartThingsExtensionOnIterable extensionsomething. -
withStart(
E start) → Iterable< E> -
Available on Iterable<
This iterable withE> , provided by the DartThingsExtensionOnIterable extensionstartat the start.