- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAlive → bool
-
Whether this poller is started or not (it can be alive when paused).
no setter
- isPaused → bool
-
Whether this poller is paused or not.
no setter
- onError → Function?
-
Error handler.
no setter
- onResult → void Function(T)
-
Result handler.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Disposes object, stopping polling.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → Future< void> - Pauses polling.
-
resume(
) → void - Resumes polling after pause.
-
start(
) → Future< void> - Initially starts polling.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited